bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGamma.__init__
=====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGamma.__init__